==> haskell-monad-loops-0.4.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-loops
version: 0.4.3
id: monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs
key: monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs
license: LicenseRef-PublicDomain
maintainer: James Cook <mokus@deepbondi.net>
author: James Cook <mokus@deepbondi.net>
stability: provisional
homepage: https://github.com/mokus0/monad-loops
synopsis: Monadic loops
description:
    Some useful control operators for looping.
    .
    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.
    .
    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.
category: Control
abi: 169ceee9ae683d41008e7f14821d1ce1
exposed: True
exposed-modules:
    Control.Monad.Loops
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-loops-0.4.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-loops-0.4.3
hs-libraries: HSmonad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html: /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-loops-0.4.3-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-loops
version: 0.4.3
id: monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA
key: monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA
license: LicenseRef-PublicDomain
maintainer: James Cook <mokus@deepbondi.net>
author: James Cook <mokus@deepbondi.net>
stability: provisional
homepage: https://github.com/mokus0/monad-loops
synopsis: Monadic loops
description:
    Some useful control operators for looping.
    .
    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.
    .
    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.
category: Control
abi: efc86605f1ef97fd65d0a61e9b7a50ba
exposed: True
exposed-modules:
    Control.Monad.Loops
import-dirs: /usr/lib/ghc-8.6.1/site-local/monad-loops-0.4.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/monad-loops-0.4.3
hs-libraries: HSmonad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html: /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
